'use strict';

var backendPluginApi = require('@backstage/backend-plugin-api');
var errors = require('@backstage/errors');

const migrationsDir = backendPluginApi.resolvePackagePath(
  "@backstage/plugin-user-settings-backend",
  "migrations"
);
class DatabaseUserSettingsStore {
  constructor(db) {
    this.db = db;
  }
  static async create(options) {
    const { database } = options;
    const client = await database.getClient();
    if (!database.migrations?.skip) {
      await client.migrate.latest({
        directory: migrationsDir
      });
    }
    return new DatabaseUserSettingsStore(client);
  }
  async get(options) {
    const rows = await this.db("user_settings").where({
      user_entity_ref: options.userEntityRef,
      bucket: options.bucket,
      key: options.key
    }).select(["bucket", "key", "value"]);
    if (!rows.length) {
      throw new errors.NotFoundError(
        `Unable to find '${options.key}' in bucket '${options.bucket}'`
      );
    }
    return {
      bucket: rows[0].bucket,
      key: rows[0].key,
      value: JSON.parse(rows[0].value)
    };
  }
  async set(options) {
    await this.db("user_settings").insert({
      user_entity_ref: options.userEntityRef,
      bucket: options.bucket,
      key: options.key,
      value: JSON.stringify(options.value)
    }).onConflict(["user_entity_ref", "bucket", "key"]).merge(["value"]);
  }
  async delete(options) {
    await this.db("user_settings").where({
      user_entity_ref: options.userEntityRef,
      bucket: options.bucket,
      key: options.key
    }).delete();
  }
}

exports.DatabaseUserSettingsStore = DatabaseUserSettingsStore;
//# sourceMappingURL=DatabaseUserSettingsStore.cjs.js.map
